
from distutils.core import setup
setup(
  name='turkishcliticss',
  version='0.0.2',
  description='This is a deep learning based library for handling Turkish clitics such as "da-de-ki-mi".',
  url='https://github.com/umitylmz/turkish-clitics/archive/v_001.tar.gz',  
  author='Ümit Yılmaz',
  author_email='umitylmz98@gmail.com',
  license='MIT', 
  keywords='nlp', 
  install_requires=[
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3'     #Specify which pyhton versions that you want to support
  ],
)